from __future__ import annotations

from typing import List

from .SubstructureGenerateFrequency import SubstructureGenerateFrequency

SubstructureGenerateFrequencyArray = List[SubstructureGenerateFrequency]
